/******************************************************************
Copyright (c) 1996 Novell, Inc. All Rights Reserved.

THIS WORK IS SUBJECT TO U.S. AND INTERNATIONAL COPYRIGHT LAWS AND
TREATIES. USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE
LICENSE AGREEMENT ACCOMPANYING THE SOFTWARE DEVELOPMENT KIT (SDK)
THAT CONTAINS THIS WORK. PURSUANT TO THE SDK LICENSE AGREEMENT,
NOVELL HEREBY GRANTS TO DEVELOPER A ROYALTY-FREE, NON-EXCLUSIVE
LICENSE TO INCLUDE NOVELL'S SAMPLE CODE IN ITS PRODUCT. NOVELL
GRANTS DEVELOPER WORLDWIDE DISTRIBUTION RIGHTS TO MARKET,
DISTRIBUTE, OR SELL NOVELL'S SAMPLE CODE AS A COMPONENT OF
DEVELOPER'S PRODUCTS. NOVELL SHALL HAVE NO OBLIGATIONS TO
DEVELOPER OR DEVELOPER'S CUSTOMERS WITH RESPECT TO THIS CODE.
******************************************************************/

package com.novell.nds.dirxml.driver.jdbc.db;


import com.novell.nds.dirxml.driver.Trace;

import java.sql.Connection;
import java.sql.SQLException;


/**
 *  Database-independent interface used to determine connection
 *  state.
 *  <br><br>
 *  All subclasses MUST have a public constructor
 *  with no parameters.
 */
public
interface DBConnectionTester
{


    /**
     * Returns the state of <code>connection</code>.
     * <br><br>
     * This method MUST NOT close or change the state of the passed connection.
     * It is recommended that at most one <code>Statement</code>
     * object be allocated.  All operations MUST be read-only.
     * This method MUST close any allocated
     * <code>Statement</code> or <code>ResultSet</code> objects.
     * A finally block is recommended for this purpose.
     * Disregarding these constraints will likely cause the driver to malfunction.
     * <br><br>
     * @param connection the connection being tested; will not be <code>null</code>
     * @param trace allows messages to be output to DSTrace; will not be <code>null</code>
     * @return <code>true</code> if <code>connection</code> is bad;
     * <code>false</code> if <code>connection</code> is good
     * @since version 1
     * @deprecated
     */
    public
    boolean
    isBad
    (
        Connection connection,
        Trace trace
    );


    /**
     * Returns the state of <code>connection</code>.
     * <br><br>
     * This method MUST NOT close of change the state of the passed connection.
     * It is recommended that at most one <code>Statement</code>
     * object be allocated.  All operations MUST be read-only.
     * This method MUST close any allocated
     * <code>Statement</code> or <code>ResultSet</code> objects.
     * A finally block is recommended for this purpose.
     * Disregarding these constraints will likely cause the driver to malfunction.
     * <br><br>
     * @param connection the connection being tested; will not be <code>null</code>
     * @param sql contains database-specific error code info; will not be <code>null</code>
     * @param trace allows messages to be output to DSTrace; will not be <code>null</code>
     * @return <code>true</code> if <code>connection</code> is bad;
     * <code>false</code> if <code>connection</code> is good
     * @since version 2
     */
    public
    boolean
    isBad
    (
        Connection connection,
        SQLException sql,
        Trace trace
    );


    /**
     * Returns whether a timeout or retry condition has been encountered.
     * <br><br>
     * This method MUST NOT close of change the state of the passed connection.
     * It is recommended that at most one <code>Statement</code>
     * object be allocated.  All operations MUST be read-only.
     * This method MUST close any allocated
     * <code>Statement</code> or <code>ResultSet</code> objects.
     * A finally block is recommended for this purpose.
     * Disregarding these constraints will likely cause the driver to malfunction.
     * <br><br>
     * @param connection the connection object that generated <code>sql</code>; will not be <code>null</code>
     * @param sql contains database-specific error code info; will not be <code>null</code>
     * @param trace allows messages to be output to DSTrace; will not be <code>null</code>
     * @return <code>true</code> if a retry condition has been detected;
     * <code>false</code> otherwise
     * @since version 3
     */
    public
    boolean
    isRetry
    (
        Connection connection,
        SQLException sql,
        Trace trace
    );


    /**
     * Returns whether an authentication error has been encountered.
     * <br><br>
     * This method MUST NOT close of change the state of the passed connection.
     * It is recommended that at most one <code>Statement</code>
     * object be allocated.  All operations MUST be read-only.
     * This method MUST close any allocated
     * <code>Statement</code> or <code>ResultSet</code> objects.
     * A finally block is recommended for this purpose.
     * Disregarding these constraints will likely cause the driver to malfunction.
     * <br><br>
     * @param connection the connection object that generated <code>sql</code>; will not be <code>null</code>
     * @param sql contains database-specific error code info; will not be <code>null</code>
     * @param trace allows messages to be output to DSTrace; will not be <code>null</code>
     * @return <code>true</code> if an authentication error has been detected;
     * <code>false</code> otherwise
     * @since version 3
     */
    public
    boolean
    isAuthFailure
    (
        Connection connection,
        SQLException sql,
        Trace trace
    );


    /**
     * Returns whether a fatal error has been encountered.
     * <br><br>
     * This method MUST NOT close of change the state of the passed connection.
     * It is recommended that at most one <code>Statement</code>
     * object be allocated.  All operations MUST be read-only.
     * This method MUST close any allocated
     * <code>Statement</code> or <code>ResultSet</code> objects.
     * A finally block is recommended for this purpose.
     * Disregarding these constraints will likely cause the driver to malfunction.
     * <br><br>
     * @param connection the connection object that generated <code>sql</code>; will not be <code>null</code>
     * @param sql contains database-specific error code info; will not be <code>null</code>
     * @param trace allows messages to be output to DSTrace; will not be <code>null</code>
     * @return <code>true</code> if a fatal error has been detected;
     * <code>false</code> otherwise
     * @since version 3
     */
    public
    boolean
    isFatal
    (
        Connection connection,
        SQLException sql,
        Trace trace
    );

}//interface DBConnectionTester
